@@ -16,16 +16,10 @@ package Gitolite::Common;
           dd
           t_start
           t_lap
-
-          ssh_fingerprint_file
-          ssh_fingerprint_line
-
-          update_hook_present
 );
 #>>>
 use Exporter 'import';
 use File::Path qw(mkpath);
-use File::Temp qw(tempfile);
 use Carp qw(carp cluck croak confess);
 
 use strict;
@@ -119,20 +113,19 @@ sub _die {
 $SIG{__DIE__} = \&_die;
 
 sub usage {
+    _warn(shift) if @_;
     my $script = (caller)[1];
-    my $function = shift if @_ and $_[0] =~ /^[\w-]+$/;
-    $function ||= ( ( ( caller(1) )[3] ) || ( ( caller(0) )[3] ) );
+    my $function = ( ( ( caller(1) )[3] ) || ( ( caller(0) )[3] ) );
     $function =~ s/.*:://;
     my $code = slurp($script);
     $code =~ /^=for $function\b(.*?)^=cut/sm;
-    say( $1 ? $1 : "...no usage message for '$function' in $script" );
+    say2( $1 ? $1 : "...no usage message in $script" );
     exit 1;
 }
 
 sub _mkdir {
-    # It's not an error if the directory exists, but it is an error if it
-    # doesn't exist and we can't create it. This includes not guaranteeing
-    # dead symlinks or if mkpath traversal is blocked by a file.
+    # it's not an error if the directory exists, but it is an error if it
+    # doesn't exist and we can't create it
     my $dir  = shift;
     my $perm = shift;    # optional
     return if -d $dir;
@@ -232,13 +225,9 @@ sub cleanup_conf_line {
         # receiving *any* arg invalidates cache)
         return \@phy_repos if ( @phy_repos and not @_ );
 
-        my $cmd = 'find . ' . ($Gitolite::Rc::rc{REPO_SYMLINKS} || '') . ' -name "*.git" -prune';
-        for my $repo (`$cmd`) {
+        for my $repo (`find . -name "*.git" -prune`) {
             chomp($repo);
-            $repo =~ s/\.git$//;
-            $repo =~ s(^\./)();
-            next if $repo =~ m(/$);
-                # tolerate non-bare repos within ~/repositories but silently ignore them
+            $repo =~ s(\./(.*)\.git$)($1);
             push @phy_repos, $repo;
         }
         trace( 3, scalar(@phy_repos) . " physical repos found" );
@@ -246,17 +235,6 @@ sub cleanup_conf_line {
     }
 }
 
-sub update_hook_present {
-    my $repo = shift;
-
-    return 1 unless -d "$ENV{GL_REPO_BASE}/$repo.git";  # non-existent repo is fine
-
-    my $x = readlink("$ENV{GL_REPO_BASE}/$repo.git/hooks/update");
-    return 1 if $x and $x eq "$ENV{GL_ADMIN_BASE}/hooks/common/update";
-
-    return 0;
-}
-
 # generate a timestamp
 sub gen_ts {
     my ( $s, $min, $h, $d, $m, $y ) = (localtime)[ 0 .. 5 ];
@@ -286,9 +264,6 @@ sub gen_lfn {
     return $template;
 }
 
-my $log_dest;
-my $syslog_opened = 0;
-END { closelog() if $syslog_opened; }
 sub gl_log {
     # the log filename and the timestamp come from the environment.  If we get
     # called even before they are set, we have no choice but to dump to STDERR
@@ -301,39 +276,6 @@ sub gl_log {
     my $ts = gen_ts();
     my $tid = $ENV{GL_TID} ||= $$;
 
-    $log_dest = $Gitolite::Rc::rc{LOG_DEST} || '' if not defined $log_dest;
-
-    # log (update records only) to "gl-log" in the bare repo dir; this is to
-    # make 'who-pushed' more efficient.  Since this is only for the update
-    # records, it is not a replacement for the other two types of logging.
-    if ($log_dest =~ /repo-log/ and $_[0] eq 'update') {
-        # if the log line is 'update', we're already in the bare repo dir
-        open my $lfh, ">>", "gl-log" or _die "open gl-log failed: $!";
-        print $lfh "$ts\t$tid\t$msg\n";
-        close $lfh;
-    }
-
-    # syslog
-    if ($log_dest =~ /syslog/) {            # log_dest *includes* syslog
-        if ($syslog_opened == 0) {
-            require Sys::Syslog;
-            Sys::Syslog->import(qw(:standard));
-
-            openlog("gitolite" . ( $ENV{GL_TID} ? "[$ENV{GL_TID}]" : "" ), "pid", $Gitolite::Rc::rc{LOG_FACILITY} || 'local0');
-            $syslog_opened = 1;
-        }
-
-        # gl_log is called either directly, or, if the rc variable LOG_EXTRA
-        # is set, from trace(1, ...).  The latter use is considered additional
-        # info for troubleshooting.  Trace prefixes a tab to the arguments
-        # before calling gl_log, to visually set off such lines in the log
-        # file.  Although syslog eats up that leading tab, we use it to decide
-        # the priority/level of the syslog message.
-        syslog( ( $msg =~ /^\t/ ? 'debug' : 'info' ), "%s", $msg);
-
-        return if $log_dest !~ /normal/;
-    }
-
     my $fh;
     logger_plus_stderr( "errors found before logging could be setup", "$msg" ) if not $ENV{GL_LOGFILE};
     open my $lfh, ">>", $ENV{GL_LOGFILE}
@@ -351,44 +293,6 @@ sub logger_plus_stderr {
     exit 1;
 }
 
-# ----------------------------------------------------------------------
-# Get the SSH fingerprint of a file
-# If the fingerprint cannot be parsed, it will be undef
-# In a scalar context, returns the fingerprint
-# In a list context, returns (fingerprint, output) where output
-# is the raw output of the ssh-keygen command
-sub ssh_fingerprint_file {
-    my $in = shift;
-    -f $in or die "file not found: $in\n";
-    my $fh;
-    open( $fh, "ssh-keygen -l -f $in |" ) or die "could not fork: $!\n";
-    my $output = <$fh>;
-    chomp $output;
-    # dbg("fp = $fp");
-    close $fh;
-    # Return a valid fingerprint or undef
-    my $fp = undef;
-    if($output =~ /((?:MD5:)?(?:[0-9a-f]{2}:){15}[0-9a-f]{2})/i or
-       $output =~ m{((?:RIPEMD|SHA)\d+:[A-Za-z0-9+/=]+)}i) {
-        $fp = $1;
-    }
-    return wantarray ? ($fp, $output) : $fp;
-}
-
-# Get the SSH fingerprint of a line of text
-# If the fingerprint cannot be parsed, it will be undef
-# In a scalar context, returns the fingerprint
-# In a list context, returns (fingerprint, output) where output
-# is the raw output of the ssh-keygen command
-sub ssh_fingerprint_line {
-    my ( $fh, $fn ) = tempfile();
-    print $fh shift() . "\n";
-    close $fh;
-    my ($fp,$output) = ssh_fingerprint_file($fn);
-    unlink $fn;
-    return wantarray ? ($fp,$output) : $fp;
-}
-
 # ----------------------------------------------------------------------
 
 # bare-minimum subset of 'Tsh' (see github.com/sitaramc/tsh)
